==> accounting-lib-2.5.0-20170323.091541-12-sources.jar: org/gcube/accounting/persistence/AccountingPersistenceFactory.java <==
/**
 * 
 */
package org.gcube.accounting.persistence;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

import org.gcube.accounting.datamodel.BasicUsageRecord;
import org.gcube.accounting.datamodel.aggregation.AggregatedServiceUsageRecord;
import org.gcube.accounting.datamodel.usagerecords.ServiceUsageRecord;
import org.gcube.documentstore.persistence.PersistenceBackendFactory;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
public class AccountingPersistenceFactory {

	private AccountingPersistenceFactory(){}
	
	protected final static Map<String, AccountingPersistence> persistences;
	
	public static void initAccountingPackages(){
		PersistenceBackendFactory.addRecordPackage(ServiceUsageRecord.class.getPackage());
		PersistenceBackendFactory.addRecordPackage(AggregatedServiceUsageRecord.class.getPackage());
		
	}
	
	static {
		persistences = new HashMap<String, AccountingPersistence>();
		initAccountingPackages();
	}
	
	public static void setFallbackLocation(String path){
		PersistenceBackendFactory.setFallbackLocation(path);
	}
	
	public synchronized static AccountingPersistence getPersistence() {
		String scope = BasicUsageRecord.getScopeFromToken();
		AccountingPersistence accountingPersistence = persistences.get(scope);
		if(accountingPersistence==null){
			accountingPersistence = new AccountingPersistence(scope);
		}
		return accountingPersistence;
	}
	
	public static void flushAll(long timeout, TimeUnit timeUnit){
		PersistenceBackendFactory.flushAll(timeout, timeUnit);
	}
	
	
	public static void shutDown(long timeout, TimeUnit timeUnit){
		//flush all and shutdown connection and thread
		PersistenceBackendFactory.flushAll(timeout, timeUnit);
		PersistenceBackendFactory.shutdown();
	}
}

==> accounting-lib-3.2.0-20180129.114725-232-sources.jar: org/gcube/accounting/persistence/AccountingPersistenceFactory.java <==
/**
 * 
 */
package org.gcube.accounting.persistence;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

import org.gcube.accounting.datamodel.BasicUsageRecord;
import org.gcube.accounting.datamodel.aggregation.AggregatedServiceUsageRecord;
import org.gcube.accounting.datamodel.usagerecords.ServiceUsageRecord;
import org.gcube.documentstore.persistence.PersistenceBackendFactory;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
public class AccountingPersistenceFactory {

	private AccountingPersistenceFactory(){}
	
	protected final static Map<String, AccountingPersistence> persistences;
	
	public static void initAccountingPackages(){
		PersistenceBackendFactory.addRecordPackage(ServiceUsageRecord.class.getPackage());
		PersistenceBackendFactory.addRecordPackage(AggregatedServiceUsageRecord.class.getPackage());
		
	}
	
	static {
		persistences = new HashMap<String, AccountingPersistence>();
		initAccountingPackages();
	}
	
	public static void setFallbackLocation(String path){
		PersistenceBackendFactory.setFallbackLocation(path);
	}
	
	public synchronized static AccountingPersistence getPersistence() {
		String context = BasicUsageRecord.getContextFromToken();
		AccountingPersistence accountingPersistence = persistences.get(context);
		if(accountingPersistence==null){
			accountingPersistence = new AccountingPersistence(context);
		}
		return accountingPersistence;
	}
	
	public static void flushAll(){
		PersistenceBackendFactory.flushAll();
	}
	
	/**
	 * Use {@link AccountingPersistenceFactory#flushAll() instead}
	 * @param timeout
	 * @param timeUnit
	 */
	@Deprecated
	public static void flushAll(long timeout, TimeUnit timeUnit){
		AccountingPersistenceFactory.flushAll();
	}
	
	public static void shutDown(){
		//flush all and shutdown connection and thread
		PersistenceBackendFactory.flushAll();
		PersistenceBackendFactory.shutdown();
	}
	
	/**
	 * Use {@link AccountingPersistenceFactory#shutDown() instead}
	 * @param timeout
	 * @param timeUnit
	 */
	@Deprecated
	public static void shutDown(long timeout, TimeUnit timeUnit){
		AccountingPersistenceFactory.shutDown();
	}
}
